
# (C) Copyright 1996 University of Toronto
# Permission to use this software for non-commerical purposes is hereby
# granted.  This software is provided "as is" without express or implied
# warranty.  This software may not be transferred or sublicensed.
# Any enhancements made by the recipient of this software shall be
# shared with the original copyright holders.

# Acknowledgements
# This software was developed as part of the project entitled "Models
# for Supporting the Analysis and Redesign of Business Processes" funded
# by the Information Technology Research Centre of Ontario.
# Principal investigators for the project are John Mylopoulos, Ray
# Reiter, Hector Levesque, Eric Yu, and Yves Lesperance.
# The i* modelling framework (including the Strategic Dependency and
# Strategic Rationale models) was developed by Eric Yu in his doctoral
# dissertation, Department of Computer Science, University of Toronto,
# 1995.
# This software was originally written by Chen Wang as part of his
# Master degree requirement.
# Substantial modifications and enhancements were made by Godfrey Cheng
# and Seyil Yoon, who worked as summer students on this project.
# The "repository" part of the code was originally written by Brian Kramer and
# subsequently modified by Chen Wang, Seyil Yoon, and Godfrey Cheng.


proc compute_context_coord {canvas tag csize} { 
     set coord [$canvas bbox $tag]
 
     return [list \
        [expr [lindex $coord 0]-$csize] \
        [expr [lindex $coord 1]-$csize] \
        [expr [lindex $coord 0]-$csize] \
        [expr [lindex $coord 3]+$csize] \
        [expr [lindex $coord 2]+$csize] \
        [expr [lindex $coord 3]+$csize] \
        [expr [lindex $coord 2]+$csize] \
        [expr [lindex $coord 1]-$csize] \
        [expr [lindex $coord 0]-$csize] \
        [expr [lindex $coord 1]-$csize]]
}

proc adjust_context_region {canvas tag} { 
     global Display_Context_Bind Display_Context_Bound

     if {[info exists Display_Context_Bind($canvas,$tag)]} {
         set csize $Display_Context_Bound(Generic)

         set ptrs [compute_context_coord $canvas $tag $csize]

         set tmp $Display_Context_Bind($canvas,$tag)

         $canvas coord $tmp \
                 [lindex $ptrs 0] [lindex $ptrs 1] \
                 [lindex $ptrs 2] [lindex $ptrs 3] \
                 [lindex $ptrs 4] [lindex $ptrs 5] \
                 [lindex $ptrs 6] [lindex $ptrs 7] \
                 [lindex $ptrs 8] [lindex $ptrs 9]
     }
}

proc create_context_region {canvas tag {status ""} {type ""}} {
     global Display_Context_Bound Display_Context_Color Display_Context_Bind
     
     if {[info exists Display_Context_Bind($canvas,$tag)] && $status == ""} {
        return 0;
     }

     if {$type == ""} {
     
        set csize $Display_Context_Bound(Generic)
        set color $Display_Context_Color(Generic)

     } else {
     
        if {[info exists Display_Context_Bound($type)]} {
            set csize $Display_Context_Bound($type)
            set color $Display_Context_Color($type)
            
        } else {
            set csize $Display_Context_Bound(Generic)
            set color $Display_Context_Color(Generic)
        }
     }
     
     if {$status == "redisplay"} {
     
        set tmp $Display_Context_Bind($canvas,$tag)
        set ptrs [$canvas coord $tmp]
        
        [$canvas create line \
            [lindex $ptrs 0] [lindex $ptrs 1] \
            [lindex $ptrs 2] [lindex $ptrs 3] \
            [lindex $ptrs 4] [lindex $ptrs 5] \
            [lindex $ptrs 6] [lindex $ptrs 7] \
            [lindex $ptrs 8] [lindex $ptrs 9] \
            -smooth 1 -splinesteps 6 -fill $color \
            -width 2.0 \
            -tag "context$tag context"]
       
     } else {
     
        set ptrs [compute_context_coord $canvas $tag $csize]

        set tmp \
            [$canvas create line \
            [lindex $ptrs 0] [lindex $ptrs 1] \
            [lindex $ptrs 2] [lindex $ptrs 3] \
            [lindex $ptrs 4] [lindex $ptrs 5] \
            [lindex $ptrs 6] [lindex $ptrs 7] \
            [lindex $ptrs 8] [lindex $ptrs 9] \
            -smooth 1 -splinesteps 6 -fill $color \
            -width 2.0 \
            -tag "context$tag context"]
     
        $canvas lower $tmp

        lower_canvas_background $canvas

        if {[info exists Display_Context_Bind($canvas,$tag)]} {
            lappend Display_Context_Bind($canvas,$tag) $tmp
        } else {
            set Display_Context_Bind($canvas,$tag) $tmp
        }
    }    
}

proc destroy_context_region {canvas tag {type ""}} {
     global Display_Context_Bound Display_Context_Color Display_Context_Bind

     if {[info exists Display_Context_Bind($canvas,$tag)]} {
         set tmp $Display_Context_Bind($canvas,$tag)
         
         $canvas delete $tmp

         unset Display_Context_Bind($canvas,$tag)
     }
}
         
