
# (C) Copyright 1996 University of Toronto
# Permission to use this software for non-commerical purposes is hereby
# granted.  This software is provided "as is" without express or implied
# warranty.  This software may not be transferred or sublicensed.
# Any enhancements made by the recipient of this software shall be
# shared with the original copyright holders.

# Acknowledgements
# This software was developed as part of the project entitled "Models
# for Supporting the Analysis and Redesign of Business Processes" funded
# by the Information Technology Research Centre of Ontario.
# Principal investigators for the project are John Mylopoulos, Ray
# Reiter, Hector Levesque, Eric Yu, and Yves Lesperance.
# The i* modelling framework (including the Strategic Dependency and
# Strategic Rationale models) was developed by Eric Yu in his doctoral
# dissertation, Department of Computer Science, University of Toronto,
# 1995.
# This software was originally written by Chen Wang as part of his
# Master degree requirement.
# Substantial modifications and enhancements were made by Godfrey Cheng
# and Seyil Yoon, who worked as summer students on this project.
# The "repository" part of the code was originally written by Brian Kramer and
# subsequently modified by Chen Wang, Seyil Yoon, and Godfrey Cheng.


proc enter_node_pos {canvas n} {
     global Display_Node_Tag Display_Node_Text Display_Node_Pos

     set tag $Display_Node_Tag($canvas,$n)
     set obj [lindex $Display_Node_Text($canvas,$tag) 1]
     set coord $Display_Node_Pos($canvas,$tag)
     
     kb_coord $canvas $obj [lindex $coord 0] [lindex $coord 1]
}

proc kb_enter_all_node_pos {canvas} {
     global Display_Nodes

     if {[info exists Display_Nodes($canvas,Actor)]} {
         foreach node $Display_Nodes($canvas,Actor) {
            enter_node_pos $canvas $node
         }
     }
     
     if {[info exists Display_Nodes($canvas,Agent)]} {
         foreach node $Display_Nodes($canvas,Agent) {
            enter_node_pos $canvas $node
         }
     }
     
     if {[info exists Display_Nodes($canvas,Role)]} {
         foreach node $Display_Nodes($canvas,Role) {
            enter_node_pos $canvas $node
         }
     }
     
     if {[info exists Display_Nodes($canvas,Position)]} {
         foreach node $Display_Nodes($canvas,Position) {
            enter_node_pos $canvas $node
         }
     }

     if {[info exists Display_Nodes($canvas,Label)]} {
         foreach node $Display_Nodes($canvas,Label) {
            enter_node_pos $canvas $node
         }
     }

     if {[info exists Display_Nodes($canvas,Alternative)]} {
        foreach node $Display_Nodes($canvas,Alternative) {        
            enter_node_pos $canvas $node
        }
     }
     
     if {[info exists Display_Nodes($canvas,Goal)]} {
         foreach node $Display_Nodes($canvas,Goal) {
            enter_node_pos $canvas $node
         }
     }

     if {[info exists Display_Nodes($canvas,Task)]} {
         foreach node $Display_Nodes($canvas,Task) {
            enter_node_pos $canvas $node
         }
     }

     if {[info exists Display_Nodes($canvas,Resource)]} {
         foreach node $Display_Nodes($canvas,Resource) {
            enter_node_pos $canvas $node
         }
     }

     if {[info exists Display_Nodes($canvas,Softgoal)]} {
         foreach node $Display_Nodes($canvas,Softgoal) {
            enter_node_pos $canvas $node
         }
     }
}

proc dump_to_file {canvas file} {
    global Display_Font Display_Size Display_Font_Tag
    
    set stream 0

    kb dump $file

    catch {set stream [open "[file rootname $file].tcg" w]} msg
    
    if {$stream != 0} {   
    
        foreach name [array names Display_Font] {
            puts $stream "Display_Font($name) $Display_Font($name)"
	    puts "Display_Font($name) $Display_Font($name)"
        }    
	foreach name [array names Display_Font_Tag] {
	    puts $stream "Display_Font_Tag($name) $Display_Font_Tag($name)"
	    puts "Display_Font_Tag($name) $Display_Font_Tag($name)"
	}


        foreach name [array names Display_Size] {
            puts $stream "Display_Size($name) $Display_Size($name)"
        }    
        close $stream
    }    
}

proc dump_file {canvas} {
     global fsBox
        
     set fsBox(pattern) *.tel*
     
     kb_enter_all_node_pos $canvas
        FSBox "Saving File"
        if {$fsBox(name) != ""} {
                dump_to_file $canvas $fsBox(path)/$fsBox(name)
        }
}

proc load_from_file {canvas file} {

    parse_design_file $canvas $file    
}

proc load_file {canvas} {
        global fsBox
        
        set fsBox(pattern) *.tel*
        
        FSBox "Loading File"
        if {$fsBox(name) != ""} {
                load_from_file $canvas $fsBox(path)/$fsBox(name)
        }

}

proc load_cfg_file {file} {
    global Display_Font Display_Size Display_Font_Tag
    
    set stream 0    
    puts $file    
    catch {set stream [open "[file rootname $file].tcg" r]} msg
    
    if {$stream != 0} {
        while {[gets $stream line] >= 0} {
            set name [lindex [split $line " "] 0]
            set value [lindex [split $line " "] 1]
            set $name $value
	    puts "set name [lindex [split $line " "] 0]"
            puts "set value [lindex [split $line " "] 1]"
            puts "set $name $value"
        }       
        close $stream
    }
}
