
# (C) Copyright 1996 University of Toronto
# Permission to use this software for non-commerical purposes is hereby
# granted.  This software is provided "as is" without express or implied
# warranty.  This software may not be transferred or sublicensed.
# Any enhancements made by the recipient of this software shall be
# shared with the original copyright holders.

# Acknowledgements
# This software was developed as part of the project entitled "Models
# for Supporting the Analysis and Redesign of Business Processes" funded
# by the Information Technology Research Centre of Ontario.
# Principal investigators for the project are John Mylopoulos, Ray
# Reiter, Hector Levesque, Eric Yu, and Yves Lesperance.
# The NFR framework was developed by Lawrence Chung in his doctoral
# dissertation, Department of Computer Science, University of Toronto,
# 1993.
# This software was written by Godfrey Cheng and Seyil Yoon, who worked
# as summer students on this project. 
# Parts of the code are adaptations of code that was developed as student
# projects at the University of Texas at Dallas, supervised by Lawrence Chung.


##################################################################
# This is the program to create UI dialog box
##################################################################

proc dialogBox {win title msgText defaultButton args} {
    global dlgButton Display_Font
    
    set fn $Display_Font(Dialog)

    ###################### create dialog window ######################

    toplevel $win -class Dialog
    wm title $win $title
    wm iconname $win "Dialog Box: $title"

    frame $win.top -relief raised -bd 1
    pack $win.top -side top -fill both
    frame $win.bot -relief raised -bd 1
    pack $win.bot -side bottom -fill both

    message $win.top.msg -width 3i -text $msgText -font $fn
    
    pack $win.top.msg -side top -expand 1 -fill both\
        -padx 3m -pady 3m


    ########################### create buttons ########################

    set i 0
    foreach bt $args {
        button $win.bot.button$i -text $bt -command "set dlgButton $i"
    
        if {$i == $defaultButton} {
    
            frame $win.bot.default -relief sunken -bd 1
            raise $win.bot.button$i
            pack $win.bot.default -side left -expand 1\
                -padx 3m -pady 2m
            pack $win.bot.button$i -in $win.bot.default\
                -side left -padx 2m -pady 2m -ipadx 2m -ipady 1m
            
        } else {
            pack $win.bot.button$i -side left -expand 1\
                -padx 3m -pady 3m -ipadx 2m -ipady 1m
        }
        incr i
    }

    #################### bind <Return> to the default button ###########

    if {$defaultButton >= 0} {

        bind $win <Return> "$win.bot.button$defaultButton flash; \
            set dlgButton $defaultButton"
    }
        
    ########################## grab and release focus ##################

    set oldFocus [focus]
    grab set $win
    focus $win
    
    tkwait variable dlgButton
    destroy $win
    focus $oldFocus
    
    return $dlgButton
}
